@@ -73,15 +73,8 @@ get_estimates <- function(geography = c("us", "region", "division", "state", "co
   }
 
 
-  if (Sys.getenv('CENSUS_API_KEY') != '') {
-
-    key <- Sys.getenv('CENSUS_API_KEY')
-
-  } else if (is.null(key)) {
-
-    stop('A Census API key is required.  Obtain one at http://api.census.gov/data/key_signup.html, and then supply the key to the `census_api_key()` function to use it throughout your tidycensus session.')
-
-  }
+  # Check for a Census API key and warn if missing
+  key <- get_census_api_key(key)
 
   if (geography == "cbsa") geography <- "metropolitan statistical area/micropolitan statistical area"
 
