@@ -47,7 +47,7 @@ utils::globalVariables(c("variable", "value", "GEOID", "NAME", "type", "moe",
                          "DATE_", "STATEFP00", "STATEFP10", "CNTYIDFP00", "CTIDFP00",
                          "BKGPIDFP00", "var_code", "val_label", "where", "pums_variables",
                          "data_type", "GEOID20", "intersection_id", "intersection_value",
-                         "level", "total", "weight_coef"))
+                         "level", "tidycensus_weight_total", "weight_coef"))
 
 #' @importFrom rlang .data
 NULL
